@@ -4,16 +4,16 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.035 qw(createSelfTiedObject);
+use IO::Compress::Base::Common 2.045 qw(createSelfTiedObject);
 
-use IO::Uncompress::Base 2.035 ;
+use IO::Uncompress::Base 2.045 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 
-$VERSION = '2.035';
+$VERSION = '2.045';
 $AnyUncompressError = '';
 
 @ISA = qw( Exporter IO::Uncompress::Base );
@@ -27,22 +27,22 @@ Exporter::export_ok_tags('all');
 
 BEGIN
 {
-   eval ' use IO::Uncompress::Adapter::Inflate 2.035 ;';
-   eval ' use IO::Uncompress::Adapter::Bunzip2 2.035 ;';
-   eval ' use IO::Uncompress::Adapter::LZO 2.035 ;';
-   eval ' use IO::Uncompress::Adapter::Lzf 2.035 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzma 2.020 ;';
-   eval ' use IO::Uncompress::Adapter::UnXz 2.020 ;';
+   eval ' use IO::Uncompress::Adapter::Inflate 2.045 ;';
+   eval ' use IO::Uncompress::Adapter::Bunzip2 2.045 ;';
+   eval ' use IO::Uncompress::Adapter::LZO 2.045 ;';
+   eval ' use IO::Uncompress::Adapter::Lzf 2.045 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzma 2.045 ;';
+   eval ' use IO::Uncompress::Adapter::UnXz 2.045 ;';
 
-   eval ' use IO::Uncompress::Bunzip2 2.035 ;';
-   eval ' use IO::Uncompress::UnLzop 2.035 ;';
-   eval ' use IO::Uncompress::Gunzip 2.035 ;';
-   eval ' use IO::Uncompress::Inflate 2.035 ;';
-   eval ' use IO::Uncompress::RawInflate 2.035 ;';
-   eval ' use IO::Uncompress::Unzip 2.035 ;';
-   eval ' use IO::Uncompress::UnLzf 2.035 ;';
-   eval ' use IO::Uncompress::UnLzma 2.035 ;';
-   eval ' use IO::Uncompress::UnXz 2.035 ;';
+   eval ' use IO::Uncompress::Bunzip2 2.045 ;';
+   eval ' use IO::Uncompress::UnLzop 2.045 ;';
+   eval ' use IO::Uncompress::Gunzip 2.045 ;';
+   eval ' use IO::Uncompress::Inflate 2.045 ;';
+   eval ' use IO::Uncompress::RawInflate 2.045 ;';
+   eval ' use IO::Uncompress::Unzip 2.045 ;';
+   eval ' use IO::Uncompress::UnLzf 2.045 ;';
+   eval ' use IO::Uncompress::UnLzma 2.045 ;';
+   eval ' use IO::Uncompress::UnXz 2.045 ;';
 }
 
 sub new
@@ -60,7 +60,7 @@ sub anyuncompress
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common 2.035 qw(:Parse);
+    use IO::Compress::Base::Common 2.045 qw(:Parse);
     return ( 'RawInflate' => [1, 1, Parse_boolean,  0] ,
              'UnLzma'     => [1, 1, Parse_boolean,  0] ) ;
 }
@@ -995,7 +995,7 @@ Same as doing this
 
 L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>
 
-L<Compress::Zlib::FAQ|Compress::Zlib::FAQ>
+L<IO::Compress::FAQ|IO::Compress::FAQ>
 
 L<File::GlobMapper|File::GlobMapper>, L<Archive::Zip|Archive::Zip>,
 L<Archive::Tar|Archive::Tar>,
