@@ -15,7 +15,7 @@ require Exporter;
 # walkoptree comes from B.xs
 
 BEGIN {
-    $B::VERSION = '1.32';
+    $B::VERSION = '1.33';
     @B::EXPORT_OK = ();
 
     # Our BOOT code needs $VERSION set, and will append to @EXPORT_OK.
@@ -347,11 +347,11 @@ B - The Perl Compiler Backend
 =head1 DESCRIPTION
 
 The C<B> module supplies classes which allow a Perl program to delve
-into its own innards. It is the module used to implement the
-"backends" of the Perl compiler. Usage of the compiler does not
+into its own innards.  It is the module used to implement the
+"backends" of the Perl compiler.  Usage of the compiler does not
 require knowledge of this module: see the F<O> module for the
-user-visible part. The C<B> module is of use to those who want to
-write new compiler backends. This documentation assumes that the
+user-visible part.  The C<B> module is of use to those who want to
+write new compiler backends.  This documentation assumes that the
 reader knows a fair amount about perl's internals including such
 things as SVs, OPs and the internal symbol table and syntax tree
 of a program.
@@ -394,12 +394,12 @@ Returns the SV object corresponding to the C variable C<sv_no>.
 
 Takes a reference to any Perl value, and turns the referred-to value
 into an object in the appropriate B::OP-derived or B::SV-derived
-class. Apart from functions such as C<main_root>, this is the primary
+class.  Apart from functions such as C<main_root>, this is the primary
 way to get an initial "handle" on an internal perl data structure
 which can then be followed with the other access methods.
 
 The returned object will only be valid as long as the underlying OPs
-and SVs continue to exist. Do not attempt to use the object after the
+and SVs continue to exist.  Do not attempt to use the object after the
 underlying structures are freed.
 
 =item amagic_generation
@@ -458,10 +458,10 @@ For example:
 
   # Walk CGI's symbol table calling print_subs on each symbol.
   # Recurse only into CGI::Util::
-  walksymtable(\%CGI::, 'print_subs', sub { $_[0] eq 'CGI::Util::' },
-               'CGI::');
+  walksymtable(\%CGI::, 'print_subs',
+               sub { $_[0] eq 'CGI::Util::' }, 'CGI::');
 
-print_subs() is a B::GV method you have declared. Also see L<"B::GV
+print_subs() is a B::GV method you have declared.  Also see L<"B::GV
 Methods">, below.
 
 =back
@@ -486,15 +486,15 @@ Returns the starting op of the main part of the Perl program.
 =item walkoptree(OP, METHOD)
 
 Does a tree-walk of the syntax tree based at OP and calls METHOD on
-each op it visits. Each node is visited before its children. If
+each op it visits.  Each node is visited before its children.  If
 C<walkoptree_debug> (see below) has been called to turn debugging on then
 the method C<walkoptree_debug> is called on each op before METHOD is
 called.
 
 =item walkoptree_debug(DEBUG)
 
-Returns the current debugging flag for C<walkoptree>. If the optional
-DEBUG argument is non-zero, it sets the debugging flag to that. See
+Returns the current debugging flag for C<walkoptree>.  If the optional
+DEBUG argument is non-zero, it sets the debugging flag to that.  See
 the description of C<walkoptree> above for what the debugging flag
 does.
 
@@ -519,7 +519,7 @@ Casts I to the internal I32 type used by that perl.
 
 =item minus_c
 
-Does the equivalent of the C<-c> command-line option. Obviously, this
+Does the equivalent of the C<-c> command-line option.  Obviously, this
 is only useful in a BEGIN block or else the flag is set too late.
 
 =item cstring(STR)
@@ -535,7 +535,7 @@ be used as a string in Perl source code.
 =item class(OBJ)
 
 Returns the class of an object without the part of the classname
-preceding the first C<"::">. This is used to turn C<"B::UNOP"> into
+preceding the first C<"::">.  This is used to turn C<"B::UNOP"> into
 C<"UNOP"> for example.
 
 =item threadsv_names
@@ -572,7 +572,7 @@ or '&PL_sv_undef').
 The C structures used by Perl's internals to hold SV and OP
 information (PVIV, AV, HV, ..., OP, SVOP, UNOP, ...) are modelled on a
 class hierarchy and the C<B> module gives access to them via a true
-object hierarchy. Structure fields which point to other objects
+object hierarchy.  Structure fields which point to other objects
 (whether types of SV or types of OP) are represented by the C<B>
 module as Perl objects of the appropriate class.
 
@@ -580,18 +580,18 @@ The bulk of the C<B> module is the methods for accessing fields of
 these structures.
 
 Note that all access is read-only.  You cannot modify the internals by
-using this module. Also, note that the B::OP and B::SV objects created
+using this module.  Also, note that the B::OP and B::SV objects created
 by this module are only valid for as long as the underlying objects
 exist; their creation doesn't increase the reference counts of the
-underlying objects. Trying to access the fields of a freed object will
+underlying objects.  Trying to access the fields of a freed object will
 give incomprehensible results, or worse.
 
 =head2 SV-RELATED CLASSES
 
 B::IV, B::NV, B::RV, B::PV, B::PVIV, B::PVNV, B::PVMG, B::BM (5.9.5 and
-earlier), B::PVLV, B::AV, B::HV, B::CV, B::GV, B::FM, B::IO. These classes
+earlier), B::PVLV, B::AV, B::HV, B::CV, B::GV, B::FM, B::IO.  These classes
 correspond in the obvious way to the underlying C structures of similar names.
-The inheritance hierarchy mimics the underlying C "inheritance". For the
+The inheritance hierarchy mimics the underlying C "inheritance".  For the
 5.10.x branch, (I<ie> 5.10.0, 5.10.1 I<etc>) this is:
 
                            B::SV
@@ -661,8 +661,8 @@ references, and a new type B::REGEXP is introduced, giving this structure:
 
 Access methods correspond to the underlying C macros for field access,
 usually with the leading "class indication" prefix removed (Sv, Av,
-Hv, ...). The leading prefix is only left in cases where its removal
-would cause a clash in method name. For example, C<GvREFCNT> stays
+Hv, ...).  The leading prefix is only left in cases where its removal
+would cause a clash in method name.  For example, C<GvREFCNT> stays
 as-is since its abbreviation would clash with the "superclass" method
 C<REFCNT> (corresponding to the C function C<SvREFCNT>).
 
@@ -677,8 +677,8 @@ C<REFCNT> (corresponding to the C function C<SvREFCNT>).
 =item object_2svref
 
 Returns a reference to the regular scalar corresponding to this
-B::SV object. In other words, this method is the inverse operation
-to the svref_2object() subroutine. This scalar and other data it points
+B::SV object.  In other words, this method is the inverse operation
+to the svref_2object() subroutine.  This scalar and other data it points
 at should be considered read-only: modifying them is neither safe nor
 guaranteed to have a sensible effect.
 
@@ -691,8 +691,8 @@ guaranteed to have a sensible effect.
 =item IV
 
 Returns the value of the IV, I<interpreted as
-a signed integer>. This will be misleading
-if C<FLAGS & SVf_IVisUV>. Perhaps you want the
+a signed integer>.  This will be misleading
+if C<FLAGS & SVf_IVisUV>.  Perhaps you want the
 C<int_value> method instead?
 
 =item IVX
@@ -736,7 +736,7 @@ unsigned.
 
 =item PV
 
-This method is the one you usually want. It constructs a
+This method is the one you usually want.  It constructs a
 string using the length and offset information in the struct:
 for ordinary scalars it will return the string that you'd see
 from Perl, even if it contains null characters.
@@ -748,14 +748,24 @@ a reference.
 
 =item PVX
 
-This method is less often useful. It assumes that the string
+This method is less often useful.  It assumes that the string
 stored in the struct is null-terminated, and disregards the
 length information.
 
 It is the appropriate method to use if you need to get the name
-of a lexical variable from a padname array. Lexical variable names
+of a lexical variable from a padname array.  Lexical variable names
 are always stored with a null terminator, and the length field
-(SvCUR) is overloaded for other purposes and can't be relied on here.
+(CUR) is overloaded for other purposes and can't be relied on here.
+
+=item CUR
+
+This method returns the internal length field, which consists of the number
+of internal bytes, not necessarily the number of logical characters.
+
+=item LEN
+
+This method returns the number of bytes allocated (via malloc) for storing
+the string.  This is 0 if the scalar does not "own" the string.
 
 =back
 
@@ -883,6 +893,15 @@ If you're working with globs at runtime, and need to disambiguate
 
 =head2 B::IO Methods
 
+B::IO objects derive from IO objects and you will get more information from
+the IO object itself.
+
+For example:
+
+  $gvio = B::svref_2object(\*main::stdin)->IO;
+  $IO = $gvio->object_2svref();
+  $fd = $IO->fileno();
+
 =over 4
 
 =item LINES
@@ -909,14 +928,31 @@ If you're working with globs at runtime, and need to disambiguate
 
 =item IoTYPE
 
+A character symbolizing the type of IO Handle.
+
+  -     STDIN/OUT
+  I     STDIN/OUT/ERR
+  <     read-only
+  >     write-only
+  a     append
+  +     read and write
+  s     socket
+  |     pipe
+  I     IMPLICIT
+  #     NUMERIC
+  space closed handle
+  \0    closed internal handle
+
 =item IoFLAGS
 
+See F<perliol.h>.
+
 =item IsSTD
 
-Takes one arguments ( 'stdin' | 'stdout' | 'stderr' ) and returns true
+Takes one argument ( 'stdin' | 'stdout' | 'stderr' ) and returns true
 if the IoIFP of the object is equal to the handle whose name was
-passed as argument ( i.e. $io->IsSTD('stderr') is true if
-IoIFP($io) == PerlIO_stdin() ).
+passed as argument; i.e., $io->IsSTD('stderr') is true if
+IoIFP($io) == PerlIO_stderr().
 
 =back
 
@@ -942,7 +978,8 @@ if running under Perl 5.9
 
 =item AvFLAGS
 
-This method returns the AV specific flags. In Perl 5.9 these are now stored
+This method returns the AV specific
+flags.  In Perl 5.9 these are now stored
 in with the main SV flags, so this method is no longer present.
 
 =back
@@ -1010,7 +1047,7 @@ C<B::OP>, C<B::UNOP>, C<B::BINOP>, C<B::LOGOP>, C<B::LISTOP>, C<B::PMOP>,
 C<B::SVOP>, C<B::PADOP>, C<B::PVOP>, C<B::LOOP>, C<B::COP>.
 
 These classes correspond in the obvious way to the underlying C
-structures of similar names. The inheritance hierarchy mimics the
+structures of similar names.  The inheritance hierarchy mimics the
 underlying C "inheritance":
 
                                  B::OP
